[gnome-builder] foundry: rename IdeBuildManager execute_async to build_async



commit f0ac95448f0078bad016cf25e77307ebb7d084db
Author: Christian Hergert <chergert redhat com>
Date:   Tue Jan 15 12:57:05 2019 -0800

    foundry: rename IdeBuildManager execute_async to build_async
    
    This renames the public API of IdeBuildManager to be build_async() which
    matches the renamed symbols in IdePipeline.

 src/libide/foundry/ide-build-manager.c             | 36 +++++++++++-----------
 src/libide/foundry/ide-build-manager.h             |  4 +--
 src/libide/foundry/ide-run-manager.c               |  4 +--
 src/plugins/autotools/ide-autotools-build-system.c |  4 +--
 src/plugins/buildui/gbp-buildui-tree-addin.c       |  2 +-
 src/plugins/cmake/gbp-cmake-build-system.c         |  4 +--
 src/plugins/meson/gbp-meson-build-system.c         |  4 +--
 7 files changed, 29 insertions(+), 29 deletions(-)
---
diff --git a/src/libide/foundry/ide-build-manager.h b/src/libide/foundry/ide-build-manager.h
index 9fcf02b8e..d34155c62 100644
--- a/src/libide/foundry/ide-build-manager.h
+++ b/src/libide/foundry/ide-build-manager.h
@@ -73,14 +73,14 @@ gboolean          ide_build_manager_rebuild_finish      (IdeBuildManager      *s
                                                          GAsyncResult         *result,
                                                          GError              **error);
 IDE_AVAILABLE_IN_3_32
-void              ide_build_manager_execute_async       (IdeBuildManager      *self,
+void              ide_build_manager_build_async       (IdeBuildManager      *self,
                                                          IdePipelinePhase         phase,
                                                          GPtrArray            *targets,
                                                          GCancellable         *cancellable,
                                                          GAsyncReadyCallback   callback,
                                                          gpointer              user_data);
 IDE_AVAILABLE_IN_3_32
-gboolean          ide_build_manager_execute_finish      (IdeBuildManager      *self,
+gboolean          ide_build_manager_build_finish      (IdeBuildManager      *self,
                                                          GAsyncResult         *result,
                                                          GError              **error);
 IDE_AVAILABLE_IN_3_32
diff --git a/src/libide/foundry/ide-run-manager.c b/src/libide/foundry/ide-run-manager.c
index f6c4baac9..082e73fa3 100644
--- a/src/libide/foundry/ide-run-manager.c
+++ b/src/libide/foundry/ide-run-manager.c
@@ -569,7 +569,7 @@ ide_run_manager_install_cb (GObject      *object,
   self = ide_task_get_source_object (task);
   g_assert (IDE_IS_RUN_MANAGER (self));
 
-  if (!ide_build_manager_execute_finish (build_manager, result, &error))
+  if (!ide_build_manager_build_finish (build_manager, result, &error))
     {
       /* We want to let the consumer know there was a build error
        * (but don't need to pass the specific error code) so that
@@ -653,7 +653,7 @@ ide_run_manager_do_install_before_run (IdeRunManager *self,
                            self,
                            G_CONNECT_SWAPPED);
 
-  ide_build_manager_execute_async (build_manager,
+  ide_build_manager_build_async (build_manager,
                                    IDE_PIPELINE_PHASE_INSTALL,
                                    NULL,
                                    ide_task_get_cancellable (task),
diff --git a/src/plugins/autotools/ide-autotools-build-system.c 
b/src/plugins/autotools/ide-autotools-build-system.c
index 81b125cd8..3685bf2a7 100644
--- a/src/plugins/autotools/ide-autotools-build-system.c
+++ b/src/plugins/autotools/ide-autotools-build-system.c
@@ -392,7 +392,7 @@ ide_autotools_build_system_get_build_flags_execute_cb (GObject      *object,
   g_assert (G_IS_FILE (file));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
-  if (!ide_build_manager_execute_finish (build_manager, result, &error))
+  if (!ide_build_manager_build_finish (build_manager, result, &error))
     {
       ide_task_return_error (task, g_steal_pointer (&error));
       IDE_EXIT;
@@ -462,7 +462,7 @@ ide_autotools_build_system_get_build_flags_async (IdeBuildSystem      *build_sys
   context = ide_object_get_context (IDE_OBJECT (self));
   build_manager = ide_build_manager_from_context (context);
 
-  ide_build_manager_execute_async (build_manager,
+  ide_build_manager_build_async (build_manager,
                                    IDE_PIPELINE_PHASE_CONFIGURE,
                                    NULL,
                                    cancellable,
diff --git a/src/plugins/buildui/gbp-buildui-tree-addin.c b/src/plugins/buildui/gbp-buildui-tree-addin.c
index a4ca6281f..52533e491 100644
--- a/src/plugins/buildui/gbp-buildui-tree-addin.c
+++ b/src/plugins/buildui/gbp-buildui-tree-addin.c
@@ -210,7 +210,7 @@ gbp_buildui_tree_addin_action_build (GSimpleAction *action,
   targets = g_ptr_array_new_full (1, g_object_unref);
   g_ptr_array_add (targets, g_object_ref (target));
 
-  ide_build_manager_execute_async (build_manager, IDE_PIPELINE_PHASE_BUILD, targets, NULL, NULL, NULL);
+  ide_build_manager_build_async (build_manager, IDE_PIPELINE_PHASE_BUILD, targets, NULL, NULL, NULL);
 }
 
 static void
diff --git a/src/plugins/cmake/gbp-cmake-build-system.c b/src/plugins/cmake/gbp-cmake-build-system.c
index 7df45c78f..684831d45 100644
--- a/src/plugins/cmake/gbp-cmake-build-system.c
+++ b/src/plugins/cmake/gbp-cmake-build-system.c
@@ -108,7 +108,7 @@ gbp_cmake_build_system_ensure_config_cb (GObject      *object,
   g_assert (G_IS_ASYNC_RESULT (result));
   g_assert (IDE_IS_TASK (task));
 
-  if (!ide_build_manager_execute_finish (build_manager, result, &error))
+  if (!ide_build_manager_build_finish (build_manager, result, &error))
     ide_task_return_error (task, g_steal_pointer (&error));
   else
     ide_task_return_boolean (task, TRUE);
@@ -134,7 +134,7 @@ gbp_cmake_build_system_ensure_config_async (GbpCMakeBuildSystem *self,
   context = ide_object_get_context (IDE_OBJECT (self));
   build_manager = ide_build_manager_from_context (context);
 
-  ide_build_manager_execute_async (build_manager,
+  ide_build_manager_build_async (build_manager,
                                    IDE_PIPELINE_PHASE_CONFIGURE,
                                    NULL,
                                    cancellable,
diff --git a/src/plugins/meson/gbp-meson-build-system.c b/src/plugins/meson/gbp-meson-build-system.c
index ba785c7f9..9b398f311 100644
--- a/src/plugins/meson/gbp-meson-build-system.c
+++ b/src/plugins/meson/gbp-meson-build-system.c
@@ -64,7 +64,7 @@ gbp_meson_build_system_ensure_config_cb (GObject      *object,
   g_assert (G_IS_ASYNC_RESULT (result));
   g_assert (IDE_IS_TASK (task));
 
-  if (!ide_build_manager_execute_finish (build_manager, result, &error))
+  if (!ide_build_manager_build_finish (build_manager, result, &error))
     ide_task_return_error (task, g_steal_pointer (&error));
   else
     ide_task_return_boolean (task, TRUE);
@@ -90,7 +90,7 @@ gbp_meson_build_system_ensure_config_async (GbpMesonBuildSystem *self,
   context = ide_object_get_context (IDE_OBJECT (self));
   build_manager = ide_build_manager_from_context (context);
 
-  ide_build_manager_execute_async (build_manager,
+  ide_build_manager_build_async (build_manager,
                                    IDE_PIPELINE_PHASE_CONFIGURE,
                                    NULL,
                                    cancellable,


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/libide/foundry/ide-build-manager.c b/src/libide/foundry/ide-build-manager.c
index 48044d358..b481a7938 100644
--- a/src/libide/foundry/ide-build-manager.c
+++ b/src/libide/foundry/ide-build-manager.c
@@ -52,7 +52,7 @@
  * as well as providing common high-level actions to plugins.
  *
  * You can use various async operations such as
- * ide_build_manager_execute_async(), ide_build_manager_clean_async(), or
+ * ide_build_manager_build_async(), ide_build_manager_clean_async(), or
  * ide_build_manager_rebuild_async() to build, clean, and rebuild respectively
  * without needing to track the build pipeline.
  *
@@ -1083,7 +1083,7 @@ ide_build_manager_action_build (IdeBuildManager *self,
 
   g_assert (IDE_IS_BUILD_MANAGER (self));
 
-  ide_build_manager_execute_async (self, IDE_PIPELINE_PHASE_BUILD, NULL, NULL, NULL, NULL);
+  ide_build_manager_build_async (self, IDE_PIPELINE_PHASE_BUILD, NULL, NULL, NULL, NULL);
 
   IDE_EXIT;
 }
@@ -1122,7 +1122,7 @@ ide_build_manager_action_install (IdeBuildManager *self,
 
   g_assert (IDE_IS_BUILD_MANAGER (self));
 
-  ide_build_manager_execute_async (self, IDE_PIPELINE_PHASE_INSTALL, NULL, NULL, NULL, NULL);
+  ide_build_manager_build_async (self, IDE_PIPELINE_PHASE_INSTALL, NULL, NULL, NULL, NULL);
 
   IDE_EXIT;
 }
@@ -1135,7 +1135,7 @@ ide_build_manager_action_export (IdeBuildManager *self,
 
   g_assert (IDE_IS_BUILD_MANAGER (self));
 
-  ide_build_manager_execute_async (self, IDE_PIPELINE_PHASE_EXPORT, NULL, NULL, NULL, NULL);
+  ide_build_manager_build_async (self, IDE_PIPELINE_PHASE_EXPORT, NULL, NULL, NULL, NULL);
 
   IDE_EXIT;
 }
@@ -1426,7 +1426,7 @@ ide_build_manager_save_all_cb (GObject      *object,
 }
 
 /**
- * ide_build_manager_execute_async:
+ * ide_build_manager_build_async:
  * @self: An #IdeBuildManager
  * @phase: An #IdePipelinePhase or 0
  * @targets: (nullable) (element-type IdeBuildTarget): an array of
@@ -1438,17 +1438,17 @@ ide_build_manager_save_all_cb (GObject      *object,
  * This function will request that @phase is completed in the underlying
  * build pipeline and execute a build. Upon completion, @callback will be
  * executed and it can determine the success or failure of the operation
- * using ide_build_manager_execute_finish().
+ * using ide_build_manager_build_finish().
  *
  * Since: 3.32
  */
 void
-ide_build_manager_execute_async (IdeBuildManager     *self,
-                                 IdePipelinePhase        phase,
-                                 GPtrArray           *targets,
-                                 GCancellable        *cancellable,
-                                 GAsyncReadyCallback  callback,
-                                 gpointer             user_data)
+ide_build_manager_build_async (IdeBuildManager     *self,
+                               IdePipelinePhase     phase,
+                               GPtrArray           *targets,
+                               GCancellable        *cancellable,
+                               GAsyncReadyCallback  callback,
+                               gpointer             user_data)
 {
   g_autoptr(IdeTask) task = NULL;
   IdeBufferManager *buffer_manager;
@@ -1463,7 +1463,7 @@ ide_build_manager_execute_async (IdeBuildManager     *self,
   cancellable = dzl_cancellable_chain (cancellable, self->cancellable);
 
   task = ide_task_new (self, cancellable, callback, user_data);
-  ide_task_set_source_tag (task, ide_build_manager_execute_async);
+  ide_task_set_source_tag (task, ide_build_manager_build_async);
   ide_task_set_priority (task, G_PRIORITY_LOW);
   ide_task_set_return_on_cancel (task, TRUE);
 
@@ -1534,21 +1534,21 @@ ide_build_manager_execute_async (IdeBuildManager     *self,
 }
 
 /**
- * ide_build_manager_execute_finish:
+ * ide_build_manager_build_finish:
  * @self: An #IdeBuildManager
  * @result: a #GAsyncResult
  * @error: A location for a #GError or %NULL
  *
  * Completes a request to ide_build_manager_execute_async().
  *
  * Returns: %TRUE if successful, otherwise %FALSE and @error is set.
  *
  * Since: 3.32
  */
 gboolean
-ide_build_manager_execute_finish (IdeBuildManager  *self,
-                                  GAsyncResult     *result,
-                                  GError          **error)
+ide_build_manager_build_finish (IdeBuildManager  *self,
+                                GAsyncResult     *result,
+                                GError          **error)
 {
   gboolean ret;
 
@@ -1534,21 +1534,21 @@ ide_build_manager_execute_async (IdeBuildManager     *self,
  * @error: A location for a #GError or %NULL
  *
- * Completes a request to ide_build_manager_execute_async().
+ * Completes a request to ide_build_manager_build_async().
  *
  * Returns: %TRUE if successful, otherwise %FALSE and @error is set.